`timescale 1ns / 1ps
module USBCommOnAtlys( 
   input clkIn, 
	// dpimref ports
	inout 	[7:0] pdb,
	input 	astb,
	input 	dstb,
	input 	pwr,
	output	pwait,
	// GPIO
	output [7:0] LED,
	input [7:0] sw,
	input clkDpim
);

	reg [7:0] LEDQ ;
	reg [7:0] swQ ;
	
	// Synchronize switches to 8MHz clock
	always @ (posedge clkIn) begin
		swQ <= sw ;
	end
	

	// LED Assignments
	reg [26:0] counter ;
	assign LED[0] = swQ[0] ;
	assign LED[1] = swQ[1] ;
	assign LED[2] = swQ[2] ;
	assign LED[7:3] = counter[26:22] ;
	
	always @ ( posedge clkIn )
	begin
		counter = counter + 1 ;
	end


	// FIFO/dpimref signals
	wire [7:0] reg0OutDpim ;
	wire reg0WrDpim ;
	wire [7:0] reg1InDpim ;
	wire reg1RdDpim ;
	wire empty ;
	wire [7:0] dout ;

	// PC to ATLYS - Reg 0
	FIFO_512x8_RdWrClks FIFO1 (
	  .wr_clk(clkDpim), // input wr_clk
	  .din(reg0OutDpim), // input [7 : 0] din
	  .wr_en(reg0WrDpim), // input wr_en
	  .full(), // output full
	  .rd_clk(clkIn), // input rd_clk
	  .rd_en(!empty), // input rd_en
	  .dout(dout), // output [7 : 0] dout
	  .empty(empty) // output empty
	);

	// ATLYS to PC - Reg 1
	FIFO_512x8_RdWrClks FIFO2 (
	  .wr_clk(clkIn), // input wr_clk
	  .din(dout), // input [15 : 0] din
	  .wr_en(!empty), // input wr_en
	  .full(), // output full
	  .rd_clk(clkDpim), // input rd_clk
	  .rd_en(reg1RdDpim), // input rd_en
	  .dout(reg1InDpim), // output [15 : 0] dout
	  .empty() // output empty
	);

	// Instantiate dpimref
	dpimref dpimref1 (
		 .mclk(clkDpim), 
		 .pdb(pdb), 
		 .astb(astb), 
		 .dstb(dstb), 
		 .pwr(pwr), 
		 .pwait(pwait), 
		 .rgLed(), 
		 .rgSwt(0), 
		 .rgBtn(0), 
		 .btn(0), 
		 .ldg(), 
		 .led(),
		 .reg0_out(reg0OutDpim), // out
		 .reg0_wr(reg0WrDpim), // out
		 .reg0_in(8'd0), // in
		 .reg0_rd(), // out
		 .reg1_out(), // out
		 .reg1_wr(), // out
		 .reg1_in(reg1InDpim), // in
		 .reg1_rd(reg1RdDpim), // out
		 .reg2_out(), // out
		 .reg2_wr(), // out
		 .reg2_in(8'd0), // in
		 .reg2_rd(), // out
		 .reg3_out(), // out
		 .reg3_wr(), // out
		 .reg3_in(8'd0), // in
		 .reg3_rd() // out 
		 ); 

endmodule


